@@ -185,10 +185,14 @@ where
 	/// Produces a contract call to the ESDT system SC,
 	/// which causes it to mint more fungible ESDT tokens.
 	/// It will fail if the SC is not the owner of the token.
-	pub fn mint(self, token_identifier: &[u8], amount: &SA::AmountType) -> ContractCall<SA, ()> {
+	pub fn mint(
+		self,
+		token_identifier: &TokenIdentifier,
+		amount: &SA::AmountType,
+	) -> ContractCall<SA, ()> {
 		let mut contract_call = self.esdt_system_sc_call_no_args(b"mint");
 
-		contract_call.push_argument_raw_bytes(token_identifier);
+		contract_call.push_argument_raw_bytes(token_identifier.as_esdt_identifier());
 		contract_call.push_argument_raw_bytes(&amount.to_bytes_be());
 
 		contract_call
@@ -196,10 +200,14 @@ where
 
 	/// Produces a contract call to the ESDT system SC,
 	/// which causes it to burn fungible ESDT tokens owned by the SC.
-	pub fn burn(self, token_identifier: &[u8], amount: &SA::AmountType) -> ContractCall<SA, ()> {
+	pub fn burn(
+		self,
+		token_identifier: &TokenIdentifier,
+		amount: &SA::AmountType,
+	) -> ContractCall<SA, ()> {
 		let mut contract_call = self.esdt_system_sc_call_no_args(b"ESDTBurn");
 
-		contract_call.push_argument_raw_bytes(token_identifier);
+		contract_call.push_argument_raw_bytes(token_identifier.as_esdt_identifier());
 		contract_call.push_argument_raw_bytes(&amount.to_bytes_be());
 
 		contract_call
@@ -207,19 +215,19 @@ where
 
 	/// The manager of an ESDT token may choose to suspend all transactions of the token,
 	/// except minting, freezing/unfreezing and wiping.
-	pub fn pause(self, token_identifier: &[u8]) -> ContractCall<SA, ()> {
+	pub fn pause(self, token_identifier: &TokenIdentifier) -> ContractCall<SA, ()> {
 		let mut contract_call = self.esdt_system_sc_call_no_args(b"pause");
 
-		contract_call.push_argument_raw_bytes(token_identifier);
+		contract_call.push_argument_raw_bytes(token_identifier.as_esdt_identifier());
 
 		contract_call
 	}
 
 	/// The reverse operation of `pause`.
-	pub fn unpause(self, token_identifier: &[u8]) -> ContractCall<SA, ()> {
+	pub fn unpause(self, token_identifier: &TokenIdentifier) -> ContractCall<SA, ()> {
 		let mut contract_call = self.esdt_system_sc_call_no_args(b"unPause");
 
-		contract_call.push_argument_raw_bytes(token_identifier);
+		contract_call.push_argument_raw_bytes(token_identifier.as_esdt_identifier());
 
 		contract_call
 	}
@@ -227,20 +235,28 @@ where
 	/// The manager of an ESDT token may freeze the tokens held by a specific account.
 	/// As a consequence, no tokens may be transferred to or from the frozen account.
 	/// Freezing and unfreezing the tokens of an account are operations designed to help token managers to comply with regulations.
-	pub fn freeze(self, token_identifier: &[u8], address: &Address) -> ContractCall<SA, ()> {
+	pub fn freeze(
+		self,
+		token_identifier: &TokenIdentifier,
+		address: &Address,
+	) -> ContractCall<SA, ()> {
 		let mut contract_call = self.esdt_system_sc_call_no_args(b"freeze");
 
-		contract_call.push_argument_raw_bytes(token_identifier);
+		contract_call.push_argument_raw_bytes(token_identifier.as_esdt_identifier());
 		contract_call.push_argument_raw_bytes(address.as_bytes());
 
 		contract_call
 	}
 
 	/// The reverse operation of `freeze`, unfreezing, will allow further transfers to and from the account.
-	pub fn unfreeze(self, token_identifier: &[u8], address: &Address) -> ContractCall<SA, ()> {
+	pub fn unfreeze(
+		self,
+		token_identifier: &TokenIdentifier,
+		address: &Address,
+	) -> ContractCall<SA, ()> {
 		let mut contract_call = self.esdt_system_sc_call_no_args(b"unFreeze");
 
-		contract_call.push_argument_raw_bytes(token_identifier);
+		contract_call.push_argument_raw_bytes(token_identifier.as_esdt_identifier());
 		contract_call.push_argument_raw_bytes(address.as_bytes());
 
 		contract_call
@@ -250,10 +266,14 @@ where
 	/// This operation is similar to burning the tokens, but the account must have been frozen beforehand,
 	/// and it must be done by the token manager.
 	/// Wiping the tokens of an account is an operation designed to help token managers to comply with regulations.
-	pub fn wipe(self, token_identifier: &[u8], address: &Address) -> ContractCall<SA, ()> {
+	pub fn wipe(
+		self,
+		token_identifier: &TokenIdentifier,
+		address: &Address,
+	) -> ContractCall<SA, ()> {
 		let mut contract_call = self.esdt_system_sc_call_no_args(b"wipe");
 
-		contract_call.push_argument_raw_bytes(token_identifier);
+		contract_call.push_argument_raw_bytes(token_identifier.as_esdt_identifier());
 		contract_call.push_argument_raw_bytes(address.as_bytes());
 
 		contract_call
@@ -266,12 +286,12 @@ where
 	pub fn set_special_roles(
 		self,
 		address: &Address,
-		token_identifier: &[u8],
+		token_identifier: &TokenIdentifier,
 		roles: &[EsdtLocalRole],
 	) -> ContractCall<SA, ()> {
 		let mut contract_call = self.esdt_system_sc_call_no_args(b"setSpecialRole");
 
-		contract_call.push_argument_raw_bytes(token_identifier);
+		contract_call.push_argument_raw_bytes(token_identifier.as_esdt_identifier());
 		contract_call.push_argument_raw_bytes(address.as_bytes());
 		for role in roles {
 			if role != &EsdtLocalRole::None {
@@ -289,12 +309,12 @@ where
 	pub fn unset_special_roles(
 		self,
 		address: &Address,
-		token_identifier: &[u8],
+		token_identifier: &TokenIdentifier,
 		roles: &[EsdtLocalRole],
 	) -> ContractCall<SA, ()> {
 		let mut contract_call = self.esdt_system_sc_call_no_args(b"unSetSpecialRole");
 
-		contract_call.push_argument_raw_bytes(token_identifier);
+		contract_call.push_argument_raw_bytes(token_identifier.as_esdt_identifier());
 		contract_call.push_argument_raw_bytes(address.as_bytes());
 		for role in roles {
 			if role != &EsdtLocalRole::None {
@@ -307,12 +327,12 @@ where
 
 	pub fn transfer_ownership(
 		self,
-		token_identifier: &[u8],
+		token_identifier: &TokenIdentifier,
 		new_owner: &Address,
 	) -> ContractCall<SA, ()> {
 		let mut contract_call = self.esdt_system_sc_call_no_args(b"transferOwnership");
 
-		contract_call.push_argument_raw_bytes(token_identifier);
+		contract_call.push_argument_raw_bytes(token_identifier.as_esdt_identifier());
 		contract_call.push_argument_raw_bytes(new_owner.as_bytes());
 
 		contract_call
@@ -320,13 +340,13 @@ where
 
 	pub fn transfer_nft_create_role(
 		self,
-		token_identifier: &[u8],
+		token_identifier: &TokenIdentifier,
 		old_creator: &Address,
 		new_creator: &Address,
 	) -> ContractCall<SA, ()> {
 		let mut contract_call = self.esdt_system_sc_call_no_args(b"transferNFTCreateRole");
 
-		contract_call.push_argument_raw_bytes(token_identifier);
+		contract_call.push_argument_raw_bytes(token_identifier.as_esdt_identifier());
 		contract_call.push_argument_raw_bytes(old_creator.as_bytes());
 		contract_call.push_argument_raw_bytes(new_creator.as_bytes());
 
